@@ -1,12 +1,13 @@
 """High level tests for Rasterio's ``GDALDataset`` abstractions."""
 
 
-import os
+from pathlib import Path
 try:
     from unittest.mock import MagicMock
 except ImportError:
     from mock import MagicMock
 
+from numpy.testing import assert_almost_equal
 import pytest
 
 import rasterio
@@ -16,12 +17,12 @@ from rasterio.transform import Affine
 
 
 def test_files(data):
-    tif = str(data.join('RGB.byte.tif'))
-    aux = tif + '.aux.xml'
+    tif = Path(data).joinpath('RGB.byte.tif')
+    aux = tif.parent.joinpath(tif.name + '.aux.xml')
     with open(aux, 'w'):
         pass
     with rasterio.open(tif) as src:
-        assert src.files == [tif, aux]
+        assert src.files == [tif.as_posix(), aux.as_posix()]
 
 
 def test_handle_closed(path_rgb_byte_tif):
@@ -47,23 +48,16 @@ def test_untiled_dataset_blocksize(tmpdir):
     """Blocksize is not relevant to untiled datasets (see #1689)"""
     tmpfile = str(tmpdir.join("test.tif"))
     with rasterio.open(
-            tmpfile, "w", driver="GTiff", count=1, height=13, width=13, dtype="uint8", crs="epsg:3857",
-            transform=Affine.identity(), blockxsize=256, blockysize=256) as dataset:
+            tmpfile, "w", driver="GTiff", count=1, height=13, width=23, dtype="uint8", crs="epsg:3857",
+            transform=Affine.identity(), blockxsize=64, blockysize=64) as dataset:
         pass
 
     with rasterio.open(tmpfile) as dataset:
         assert not dataset.profile["tiled"]
-        assert dataset.shape == (13, 13)
+        assert dataset.shape == (13, 23)
+        assert dataset.block_shapes == [(13, 23)]
 
 
-def test_tiled_dataset_blocksize_guard(tmpdir):
-    """Tiled datasets with dimensions less than blocksize are not permitted"""
-    tmpfile = str(tmpdir.join("test.tif"))
-    with pytest.raises(ValueError):
-        rasterio.open(
-            tmpfile, "w", driver="GTiff", count=1, height=13, width=13, dtype="uint8", crs="epsg:3857",
-            transform=Affine.identity(), tiled=True, blockxsize=256, blockysize=256)
-
 def test_dataset_readonly_attributes(path_rgb_byte_tif):
     """Attempts to set read-only attributes fail with DatasetAttributeError"""
     with pytest.raises(DatasetAttributeError):
@@ -76,3 +70,13 @@ def test_dataset_readonly_attributes(path_rgb_byte_tif):
     with pytest.raises(NotImplementedError):
         with rasterio.open(path_rgb_byte_tif) as dataset:
             dataset.crs = "foo"
+
+
+def test_statistics(path_rgb_byte_tif):
+    """Compute, store, and return basic statistics."""
+    with rasterio.open(path_rgb_byte_tif) as dataset:
+        stats = dataset.statistics(1)
+        assert stats.min == 0
+        assert stats.max == 255
+        assert_almost_equal(stats.mean, 29.947726688477)
+        assert_almost_equal(stats.std, 52.340921626611)
