@@ -2,6 +2,7 @@
 
 from __future__ import division
 import logging
+import shutil
 
 import affine
 import boto3
@@ -9,16 +10,17 @@ import numpy
 import pytest
 
 import rasterio
+from rasterio.control import GroundControlPoint
 from rasterio.crs import CRS
 from rasterio.enums import Resampling, MaskFlags
-from rasterio.errors import RasterioDeprecationWarning, WarpOptionsError, WarpedVRTError
+from rasterio.errors import WarpOptionsError
 from rasterio.io import MemoryFile
 from rasterio import shutil as rio_shutil
 from rasterio.vrt import WarpedVRT
 from rasterio.warp import transform_bounds
 from rasterio.windows import Window
 
-from .conftest import requires_gdal21, requires_gdal2
+from .conftest import gdal_version
 
 log = logging.getLogger(__name__)
 
@@ -41,14 +43,6 @@ def _copy_update_profile(path_in, path_out, **kwargs):
     return str(path_out)
 
 
-def test_deprecated_param(path_rgb_byte_tif):
-    """dst_crs is deprecated"""
-    with rasterio.open(path_rgb_byte_tif) as src:
-        with pytest.warns(RasterioDeprecationWarning):
-            vrt = WarpedVRT(src, dst_crs=DST_CRS)
-            assert vrt.dst_crs == CRS.from_string(DST_CRS)
-
-
 def test_warped_vrt(path_rgb_byte_tif):
     """A VirtualVRT has the expected VRT properties."""
     with rasterio.open(path_rgb_byte_tif) as src:
@@ -62,7 +56,6 @@ def test_warped_vrt(path_rgb_byte_tif):
         assert vrt.mask_flag_enums == ([MaskFlags.nodata],) * 3
 
 
-@requires_gdal21
 def test_warped_vrt_nondefault_nodata(path_rgb_byte_tif):
     """A VirtualVRT has expected nondefault nodata values."""
     with rasterio.open(path_rgb_byte_tif) as src:
@@ -76,7 +69,6 @@ def test_warped_vrt_nondefault_nodata(path_rgb_byte_tif):
         assert vrt.mask_flag_enums == ([MaskFlags.all_valid],) * 3
 
 
-@requires_gdal21(reason="Nodata deletion requires GDAL 2.1+")
 def test_warped_vrt_add_alpha(dsrec, path_rgb_byte_tif):
     """A VirtualVRT has the expected VRT properties."""
     with rasterio.Env() as env:
@@ -105,7 +97,6 @@ def test_warped_vrt_add_alpha(dsrec, path_rgb_byte_tif):
         assert "1 N GTiff" in records[0]
 
 
-@requires_gdal21(reason="Nodata deletion requires GDAL 2.1+")
 def test_warped_vrt_msk_add_alpha(path_rgb_msk_byte_tif, caplog):
     """Add an alpha band to the VRT to access per-dataset mask of a source"""
     with rasterio.open(path_rgb_msk_byte_tif) as src:
@@ -128,7 +119,6 @@ def test_warped_vrt_msk_add_alpha(path_rgb_msk_byte_tif, caplog):
         assert "RGB2.byte.tif.msk" in caplog.text
 
 
-@requires_gdal21(reason="nodata deletion requires gdal 2.1+")
 def test_warped_vrt_msk_nodata(path_rgb_msk_byte_tif, caplog):
     """Specifying dst nodata also works for source with .msk"""
     with rasterio.open(path_rgb_msk_byte_tif) as src:
@@ -212,7 +202,46 @@ def test_warp_extras(path_rgb_byte_tif):
             assert (rgb[:, 0, 0] == 255).all()
 
 
-@requires_gdal21(reason="S3 raster access requires GDAL 2.1+")
+def test_transformer_options(path_rgb_byte_tif):
+    transform = affine.Affine(
+        1.0003577499128138, 0.0, -8848646.496183893,
+        0.0, -1.0003577499128138, 720.9022505759253,
+    )
+    transformer_options = {
+        "SRC_METHOD": "NO_GEOTRANSFORM",
+        "DST_METHOD": "NO_GEOTRANSFORM",
+    }
+    with rasterio.open(path_rgb_byte_tif) as src, WarpedVRT(
+        src,
+        crs=DST_CRS,
+        **transformer_options,
+    ) as vrt:
+        for key, value in transformer_options.items():
+            assert vrt.warp_extras[key] == value
+        if gdal_version.at_least("3.2"):
+            assert vrt.transform.almost_equals(transform)
+        else:
+            assert not vrt.transform.almost_equals(transform)
+
+
+def test_transformer_options__width_height(path_rgb_byte_tif):
+    transform = affine.Affine(79.1, 0.0, 0.0, 0.0, -71.8, 718.0)
+    transformer_options = {
+        "SRC_METHOD": "NO_GEOTRANSFORM",
+        "DST_METHOD": "NO_GEOTRANSFORM",
+    }
+    with rasterio.open(path_rgb_byte_tif) as src, WarpedVRT(
+        src,
+        crs=DST_CRS,
+        width=10,
+        height=10,
+        **transformer_options,
+    ) as vrt:
+        for key, value in transformer_options.items():
+            assert vrt.warp_extras[key] == value
+        assert vrt.transform.almost_equals(transform)
+
+
 @credentials
 @pytest.mark.network
 def test_wrap_s3():
@@ -251,7 +280,7 @@ def test_crs_should_be_set(path_rgb_byte_tif, tmpdir, complex):
 
     Permalink to ``GDALCreateWarpedVRT()`` call:
 
-        https://github.com/mapbox/rasterio/blob/1f759e5f67628f163ea2550d8926b91545245712/rasterio/_warp.pyx#L753
+        https://github.com/rasterio/rasterio/blob/1f759e5f67628f163ea2550d8926b91545245712/rasterio/_warp.pyx#L753
 
     """
 
@@ -273,10 +302,10 @@ def test_crs_should_be_set(path_rgb_byte_tif, tmpdir, complex):
         vrt_options = {"dst_crs": dst_crs}
         if complex:
             vrt_options.update(
-                dst_crs=dst_crs,
-                dst_height=dst_height,
-                dst_width=dst_width,
-                dst_transform=dst_transform,
+                crs=dst_crs,
+                height=dst_height,
+                width=dst_width,
+                transform=dst_transform,
                 resampling=Resampling.nearest,
             )
 
@@ -348,14 +377,13 @@ def test_image_nodata_mask(red_green):
             assert image[64, 64, 0] == 255
 
 
-@requires_gdal2(reason="Warped VRT overviews require GDAL 2")
 def test_hit_ovr(red_green):
     """Zoomed out read hits the overviews"""
     # GDAL doesn't log overview hits for local files , so we copy the
     # overviews of green.tif over the red overviews and expect to find
     # green pixels below.
     green_ovr = red_green.join("green.tif.ovr")
-    green_ovr.rename(red_green.join("red.tif.ovr"))
+    shutil.move(green_ovr, red_green.join("red.tif.ovr"))
     assert not green_ovr.exists()
     with rasterio.open(str(red_green.join("red.tif.ovr"))) as ovr:
         data = ovr.read()
@@ -368,7 +396,6 @@ def test_hit_ovr(red_green):
         assert image[0, 0, 1] == 204
 
 
-@requires_gdal21(reason="add_alpha requires GDAL 2.1+")
 def test_warped_vrt_1band_add_alpha():
     """Add an alpha band to the VRT to access per-dataset mask of a source"""
     with rasterio.open('tests/data/shade.tif') as src:
@@ -380,7 +407,6 @@ def test_warped_vrt_1band_add_alpha():
         )
 
 
-@requires_gdal21(reason="add_alpha requires GDAL 2.1+")
 def test_invalid_add_alpha():
     """Adding an alpha band to a VRT that already has one fails"""
     with rasterio.open('tests/data/RGBA.byte.tif') as src:
@@ -429,7 +455,6 @@ def test_warpedvrt_issue1744(data):
             assert src.dtypes == vrt.dtypes == ("float32",)
 
 
-@requires_gdal2
 def test_open_datasets(capfd, path_rgb_byte_tif):
     """Number of open datasets is expected"""
     with rasterio.Env() as env:
@@ -450,7 +475,6 @@ def test_open_datasets(capfd, path_rgb_byte_tif):
         assert "1 N GTiff" not in captured.err
 
 
-@requires_gdal2
 def test_warp_warp(dsrec, path_rgb_byte_tif):
     """Vincent! :P"""
     with rasterio.Env() as env:
@@ -502,7 +526,7 @@ def test_out_dtype(red_green):
 
 
 def test_sample(red_green):
-    """See https://github.com/mapbox/rasterio/issues/1833."""
+    """See https://github.com/rasterio/rasterio/issues/1833."""
     with rasterio.Env():
         with rasterio.open(str(red_green.join("red.tif"))) as src, WarpedVRT(
             src,
@@ -615,3 +639,36 @@ def test_gauss_no(path_rgb_byte_tif):
     with rasterio.open(path_rgb_byte_tif) as src:
         with pytest.raises(Exception):
             WarpedVRT(src, resampling=Resampling.gauss)
+
+
+def test_warpedvrt_gcps__width_height(tmp_path):
+    tiffname = tmp_path / "test.tif"
+    src_gcps = [
+        GroundControlPoint(row=0, col=0, x=156113, y=2818720, z=0),
+        GroundControlPoint(row=0, col=800, x=338353, y=2785790, z=0),
+        GroundControlPoint(row=800, col=800, x=297939, y=2618518, z=0),
+        GroundControlPoint(row=800, col=0, x=115698, y=2651448, z=0),
+    ]
+    crs = CRS.from_epsg(32618)
+    with rasterio.open(tiffname, mode='w', height=800, width=800, count=3, dtype=numpy.uint8) as source:
+        source.gcps = (src_gcps, crs)
+
+    with rasterio.open(tiffname) as src:
+        with WarpedVRT(src, width=10, height=10) as vrt:
+            assert vrt.height == 10
+            assert vrt.width == 10
+            assert vrt.crs == crs
+            assert vrt.dst_transform.almost_equals(
+                affine.Affine(22271.389322449897, 0.0, 115698.25, 0.0, -20016.05875815117, 2818720.0)
+            )
+
+
+def test_warpedvrt_rpcs__width_height():
+    with rasterio.open('tests/data/RGB.byte.rpc.vrt') as src:
+        with WarpedVRT(src, src_crs="EPSG:4326", width=10, height=10) as vrt:
+            assert vrt.height == 10
+            assert vrt.width == 10
+            assert vrt.crs == CRS.from_epsg(4326)
+            assert vrt.dst_transform.almost_equals(
+                affine.Affine(0.008598908695300157, 0.0, -123.48824818566573, 0.0, -0.0041566403046337285, 49.52797830474037)
+            )
